"""Module for evolution requirements fixtures"""
# pylint: disable=redefined-outer-name

import random

from pytest import fixture

from tests import genotypes


@fixture(scope="function", autouse=True)
def set_random_seed():
    """Fix the random seed for repeatable testing"""
    random.seed(1)


@fixture(scope="package", params=["OneHaploid", "OneDiploid"])
def genotype(request):
    """Fixture to return the phenotype generator"""
    return genotypes.__dict__[request.param]


@fixture(scope="package")
def phenotype(phenotype_gen):
    """Fixture to return a phenotype instance"""
    return phenotype_gen()



"""Module for test genotypes"""
from gevopy import genetics, random


class OneHaploid(genetics.GenotypeModel):
    """Simple and most basic haploid genotype"""
    chromosome: genetics.Haploid = genetics.Field(
        default_factory=lambda: random.haploid(size=12)
    )


class OneDiploid(genetics.GenotypeModel):
    """Simple and most basic diploid genotype"""
    chromosome: genetics.Diploid = genetics.Field(
        default_factory=lambda: random.diploid(size=12)
    )
